#
# django-codenerix-payments
#
# Codenerix GNU
#
# Project URL : http://www.codenerix.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


def url_path(url, action):
    return "/{}action/[a-zA-Z0-9]+/{}/$".format(url, action)


def url_success(url):
    return url_path(url, "success")


def url_confirm(url):
    return url_path(url, "confirm")


def url_cancel(url):
    return url_path(url, "cancel")
